@@ -1,5 +1,6 @@
 /*
 Copyright 2008-2009 Nick Shaforostoff <shaforostoff@kde.ru>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -512,8 +513,7 @@ QString XliffStorage::target(const DocPosition& pos) const
 QString XliffStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
 {
     QString str = source(pos);
-    if (truncateFirstLine)
-    {
+    if (truncateFirstLine) {
         int truncatePos = str.indexOf("\n");
         if (truncatePos != -1)
             str.truncate(truncatePos);
@@ -523,8 +523,7 @@ QString XliffStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFir
 QString XliffStorage::targetWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
 {
     QString str = target(pos);
-    if (truncateFirstLine)
-    {
+    if (truncateFirstLine) {
         int truncatePos = str.indexOf("\n");
         if (truncatePos != -1)
             str.truncate(truncatePos);
